# redial

redial is a simple shell application that manages your SSH sessions.

![redial](https://github.com/taypo/redial/blob/master/doc/redial.png?raw=true)

You can install it with pip.

`pip3 install redial` 

Features
- [x] Manage your connections in folders/groups
- [x] Open a file manager to your remote host (Midnight Commander should be installed)
- [ ] Edit/Move/Delete connection
- [ ] Copy SSH Key to remote host

More features coming soon..
